/*
 * RTC (real-time clock) support for the X1600.
 *
 * Copyright (C) 2023, 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <l4/sys/types.h>
#include <stdint.h>



#ifdef __cplusplus

#include <l4/devices/rtc-generic.h>

class Rtc_x1600_chip : public Rtc_chip
{
protected:
  void _pre_power_down();

public:
  explicit Rtc_x1600_chip(l4_addr_t addr, Cpm_chip *cpm = NULL);
};

Rtc_chip *x1600_rtc_chip(l4_addr_t rtc_base, Cpm_chip *cpm);

#endif /* __cplusplus */



/* C language interface. */

EXTERN_C_BEGIN

void *x1600_rtc_init(l4_addr_t rtc_base, void *cpm);

enum Clock_identifiers x1600_rtc_get_clock(void *rtc);

void x1600_rtc_disable(void *rtc);

void x1600_rtc_enable(void *rtc);

void x1600_rtc_alarm_disable(void *rtc);

void x1600_rtc_alarm_enable(void *rtc);

void x1600_rtc_wakeup_alarm_disable(void *rtc);

void x1600_rtc_wakeup_alarm_enable(void *rtc);

uint32_t x1600_rtc_get_seconds(void *rtc);

void x1600_rtc_set_seconds(void *rtc, uint32_t seconds);

uint32_t x1600_rtc_get_alarm_seconds(void *rtc);

void x1600_rtc_set_alarm_seconds(void *rtc, uint32_t seconds);

void x1600_rtc_set_regulator(void *rtc, uint32_t base, uint32_t adjustment);

void x1600_rtc_hibernate(void *rtc);

void x1600_rtc_power_down(void *rtc);

EXTERN_C_END
